==> aws-java-sdk-1.8.4-sources.jar: com/amazonaws/services/logs/model/transform/LogStreamJsonUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.logs.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.logs.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * Log Stream JSON Unmarshaller
 */
public class LogStreamJsonUnmarshaller implements Unmarshaller<LogStream, JsonUnmarshallerContext> {

    public LogStream unmarshall(JsonUnmarshallerContext context) throws Exception {
        LogStream logStream = new LogStream();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.currentToken;
        if (token == null) token = context.nextToken();
        if (token == VALUE_NULL) return null;

        while (true) {
            if (token == null) break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("logStreamName", targetDepth)) {
                    context.nextToken();
                    logStream.setLogStreamName(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("creationTime", targetDepth)) {
                    context.nextToken();
                    logStream.setCreationTime(LongJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("firstEventTimestamp", targetDepth)) {
                    context.nextToken();
                    logStream.setFirstEventTimestamp(LongJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("lastEventTimestamp", targetDepth)) {
                    context.nextToken();
                    logStream.setLastEventTimestamp(LongJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("lastIngestionTime", targetDepth)) {
                    context.nextToken();
                    logStream.setLastIngestionTime(LongJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("uploadSequenceToken", targetDepth)) {
                    context.nextToken();
                    logStream.setUploadSequenceToken(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("arn", targetDepth)) {
                    context.nextToken();
                    logStream.setArn(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("storedBytes", targetDepth)) {
                    context.nextToken();
                    logStream.setStoredBytes(LongJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null || context.getLastParsedParentElement().equals(currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth) break;
                }
            }

            token = context.nextToken();
        }
        
        return logStream;
    }

    private static LogStreamJsonUnmarshaller instance;
    public static LogStreamJsonUnmarshaller getInstance() {
        if (instance == null) instance = new LogStreamJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-1.8.9.1-sources.jar: com/amazonaws/services/logs/model/transform/LogStreamJsonUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.logs.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.logs.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * Log Stream JSON Unmarshaller
 */
public class LogStreamJsonUnmarshaller implements Unmarshaller<LogStream, JsonUnmarshallerContext> {

    public LogStream unmarshall(JsonUnmarshallerContext context) throws Exception {
        LogStream logStream = new LogStream();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null) token = context.nextToken();
        if (token == VALUE_NULL) return null;

        while (true) {
            if (token == null) break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("logStreamName", targetDepth)) {
                    context.nextToken();
                    logStream.setLogStreamName(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("creationTime", targetDepth)) {
                    context.nextToken();
                    logStream.setCreationTime(LongJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("firstEventTimestamp", targetDepth)) {
                    context.nextToken();
                    logStream.setFirstEventTimestamp(LongJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("lastEventTimestamp", targetDepth)) {
                    context.nextToken();
                    logStream.setLastEventTimestamp(LongJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("lastIngestionTime", targetDepth)) {
                    context.nextToken();
                    logStream.setLastIngestionTime(LongJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("uploadSequenceToken", targetDepth)) {
                    context.nextToken();
                    logStream.setUploadSequenceToken(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("arn", targetDepth)) {
                    context.nextToken();
                    logStream.setArn(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("storedBytes", targetDepth)) {
                    context.nextToken();
                    logStream.setStoredBytes(LongJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null || context.getLastParsedParentElement().equals(currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth) break;
                }
            }

            token = context.nextToken();
        }
        
        return logStream;
    }

    private static LogStreamJsonUnmarshaller instance;
    public static LogStreamJsonUnmarshaller getInstance() {
        if (instance == null) instance = new LogStreamJsonUnmarshaller();
        return instance;
    }
}
